Package: lcars
Title: LCARS Aesthetic for Shiny
Version: 0.4.1
Authors@R: person("Matthew", "Leonawicz", email = "rpkgs@pm.me", role = c("aut", "cre"), comment = c(ORCID = "0000-0001-9452-2771"))
Description: Provides Shiny widgets and theme that support a 'Library Computer Access/Retrieval System' (LCARS) aesthetic for Shiny apps. 
    The package also includes functions for adding a minimal LCARS theme to static 'ggplot2' graphs. 
    More details about LCARS can be found at <https://en.wikipedia.org/wiki/LCARS>.
License: MIT + file LICENSE
URL: https://github.com/leonawicz/lcars
BugReports: https://github.com/leonawicz/lcars/issues
Depends: R (>= 3.5.0)
Imports: grid, ggplot2, shiny, trekcolors
Suggests: testthat, knitr, rmarkdown, png, ggrepel, showtext, leaflet,
        leaflet.extras
VignetteBuilder: knitr
Encoding: UTF-8
Language: en-US
LazyData: true
RoxygenNote: 7.3.2
NeedsCompilation: no
Packaged: 2025-06-13 21:25:11 UTC; Matt
Author: Matthew Leonawicz [aut, cre] (ORCID:
    <https://orcid.org/0000-0001-9452-2771>)
Maintainer: Matthew Leonawicz <rpkgs@pm.me>
Repository: CRAN
Date/Publication: 2025-06-13 22:10:02 UTC
Built: R 4.6.0; ; 2026-04-26 13:45:34 UTC; unix
